@@ -18,4 +18,5 @@ int gpio_sequence_resume(struct EG25Manager *state);
 int gpio_sequence_wake(struct EG25Manager *state);
 int gpio_sequence_sleep(struct EG25Manager *state);
 
-gboolean gpio_check_poweroff(struct EG25Manager *manager, gboolean keep_down);
+void gpio_force_off(struct EG25Manager *manager);
+gboolean gpio_check_poweroff(struct EG25Manager *manager);
